@@ -17,7 +17,7 @@ our @EXPORT_OK = qw(
     );
 our @EXPORT = @EXPORT_OK;
 
-our $VERSION="3.1.01";
+our $VERSION="3.1.02";
 
 our @MANIFEST = (
 'clear.sh',
@@ -1509,10 +1509,10 @@ GRANTS_MYSQL
 
 use mysql;
 set password='_DBPASSWORD_';
-delete from tables_priv;
-delete from columns_priv;
-delete from db;
-delete from user where user != 'root';
+-- delete from tables_priv;
+-- delete from columns_priv;
+-- delete from db;
+delete from user where user not in ('root', 'mysql.sys');
 
 flush privileges;
 
